@@ -1,9 +1,3 @@
-# Run test ie with: rspec spec/unit/provider/nova_spec.rb
-
-# Add openstacklib code to $LOAD_PATH so that we can load this during
-# standalone compiles without error.
-File.expand_path('../../../../openstacklib/lib', File.dirname(__FILE__)).tap { |dir| $LOAD_PATH.unshift(dir) unless $LOAD_PATH.include?(dir) }
-
 require 'puppet/util/inifile'
 require 'puppet/provider/openstack'
 require 'puppet/provider/openstack/auth'
@@ -13,15 +7,24 @@ class Puppet::Provider::Nova < Puppet::Provider::Openstack
 
   extend Puppet::Provider::Openstack::Auth
 
-  def self.request(service, action, properties=nil)
+  def self.project_request(service, action, properties=nil, options={})
+    self.request(service, action, properties, options, 'project')
+  end
+
+  def self.system_request(service, action, properties=nil, options={})
+    self.request(service, action, properties, options, 'system')
+  end
+
+  def self.request(service, action, properties=nil, options={}, scope='project')
     begin
       super
     rescue Puppet::Error::OpenstackAuthInputError => error
-      nova_request(service, action, error, properties)
+      nova_request(service, action, error, properties, options)
     end
   end
 
-  def self.nova_request(service, action, error, properties=nil)
+  def self.nova_request(service, action, error, properties=nil, options={})
+    warning('Usage of keystone_authtoken parameters is deprecated.')
     properties ||= []
     @credentials.username = nova_credentials['username']
     @credentials.password = nova_credentials['password']
@@ -33,7 +36,7 @@ class Puppet::Provider::Nova < Puppet::Provider::Openstack
       @credentials.region_name = nova_credentials['region_name']
     end
     raise error unless @credentials.set?
-    Puppet::Provider::Openstack.request(service, action, properties, @credentials)
+    Puppet::Provider::Openstack.request(service, action, properties, @credentials, options)
   end
 
   def self.nova_manage_request(*args)
@@ -120,17 +123,8 @@ class Puppet::Provider::Nova < Puppet::Provider::Openstack
   end
 
   def self.reset
+    @auth_endpoint = nil
     @nova_conf = nil
     @nova_credentials = nil
   end
-
-  def self.str2hash(s)
-    #parse string
-    if s.include? "="
-      k, v = s.split("=", 2)
-      return {k.gsub(/'/, "") => v.gsub(/'/, "")}
-    else
-      return s.gsub(/'/, "")
-    end
-  end
 end
