@@ -35,7 +35,6 @@ describe 'nova::api' do
         )
         is_expected.to contain_package('nova-api').that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package('nova-api').that_notifies('Anchor[nova::install::end]')
-        is_expected.to_not contain_exec('validate_nova_api')
       end
 
       it 'enable metadata in evenlet configuration' do
@@ -67,32 +66,40 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/enable_instance_password').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(false)
+        is_expected.to contain_nova_config('api/instance_list_per_project_cells').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/instance_list_cells_batch_strategy').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/instance_list_cells_batch_fixed_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/list_records_by_skipping_down_cells').with_value('<SERVICE DEFAULT>')
       end
     end
 
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :enabled                      => false,
-          :ensure_package               => '2012.1-2',
-          :api_bind_address             => '192.168.56.210',
-          :metadata_listen              => '127.0.0.1',
-          :metadata_listen_port         => 8875,
-          :osapi_compute_listen_port    => 8874,
-          :use_forwarded_for            => false,
-          :osapi_compute_workers        => 1,
-          :metadata_workers             => 2,
-          :enable_proxy_headers_parsing => true,
-          :max_request_body_size        => '102400',
-          :max_limit                    => 1000,
-          :compute_link_prefix          => 'https://10.0.0.1:7777/',
-          :glance_link_prefix           => 'https://10.0.0.1:6666/',
-          :hide_server_address_states   => 'building',
-          :allow_instance_snapshots     => true,
-          :enable_network_quota         => false,
-          :enable_instance_password     => true,
-          :password_length              => 12,
-          :allow_resize_to_same_host    => true,
+          :enabled                              => false,
+          :ensure_package                       => '2012.1-2',
+          :api_bind_address                     => '192.168.56.210',
+          :metadata_listen                      => '127.0.0.1',
+          :metadata_listen_port                 => 8875,
+          :osapi_compute_listen_port            => 8874,
+          :use_forwarded_for                    => false,
+          :osapi_compute_workers                => 1,
+          :metadata_workers                     => 2,
+          :enable_proxy_headers_parsing         => true,
+          :max_request_body_size                => '102400',
+          :max_limit                            => 1000,
+          :compute_link_prefix                  => 'https://10.0.0.1:7777/',
+          :glance_link_prefix                   => 'https://10.0.0.1:6666/',
+          :hide_server_address_states           => 'building',
+          :allow_instance_snapshots             => true,
+          :enable_network_quota                 => false,
+          :enable_instance_password             => true,
+          :password_length                      => 12,
+          :allow_resize_to_same_host            => true,
+          :instance_list_per_project_cells      => false,
+          :instance_list_cells_batch_strategy   => 'distributed',
+          :instance_list_cells_batch_fixed_size => 100,
+          :list_records_by_skipping_down_cells  => true,
         })
       end
 
@@ -132,83 +139,21 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/enable_instance_password').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/password_length').with_value('12')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with_value(true)
+        is_expected.to contain_nova_config('api/instance_list_per_project_cells').with_value(false)
+        is_expected.to contain_nova_config('api/instance_list_cells_batch_strategy').with_value('distributed')
+        is_expected.to contain_nova_config('api/instance_list_cells_batch_fixed_size').with_value(100)
+        is_expected.to contain_nova_config('api/list_records_by_skipping_down_cells').with_value(true)
       end
     end
 
-    context 'while validating the service with default command' do
-      before do
-        params.merge!({
-          :validate => true,
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
-        :command   => 'nova --os-auth-url http://127.0.0.1:5000/ --os-project-name services --os-username novae --os-password passw0rd flavor-list',
-        :subscribe => 'Service[nova-api]',
-      )}
-
-    end
-
-    context 'while validating the service with custom command' do
-      before do
-        params.merge!({
-          :validate            => true,
-          :validation_options  => { 'nova-api' => { 'command' => 'my-script' } }
-        })
-      end
-      it { is_expected.to contain_openstacklib__service_validation('nova-api').with(
-        :command   => 'my-script',
-        :subscribe => 'Service[nova-api]',
-      )}
-    end
-
     context 'while not managing service state' do
       before do
         params.merge!({
-          :enabled        => false,
           :manage_service => false,
         })
       end
 
-      it { is_expected.to contain_service('nova-api').without_ensure }
-    end
-
-    context 'with default database parameters' do
-      let :pre_condition do
-        "include nova::db
-         class { 'nova::keystone::authtoken':
-           password => 'a_big_secret',
-         }"
-      end
-
-      it { is_expected.to_not contain_nova_config('database/connection') }
-      it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('api_database/connection') }
-      it { is_expected.to_not contain_nova_config('api_database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'with overridden database parameters' do
-      let :pre_condition do
-        "class { 'nova::db':
-           database_connection              => 'mysql://user:pass@db/db1',
-           slave_connection                 => 'mysql://user:pass@slave/db1',
-           api_database_connection          => 'mysql://user:pass@db/db2',
-           api_slave_connection             => 'mysql://user:pass@slave/db2',
-           database_connection_recycle_time => '30',
-         }
-         class { 'nova::keystone::authtoken':
-           password => 'passw0rd',
-         }
-        "
-      end
-
-      it { is_expected.to contain_nova_config('api_database/connection').with_value('mysql://user:pass@db/db2').with_secret(true) }
-      it { is_expected.to contain_nova_config('api_database/slave_connection').with_value('mysql://user:pass@slave/db2').with_secret(true) }
-      it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection              => 'mysql://user:pass@db/db1',
-        :slave_connection        => 'mysql://user:pass@slave/db1',
-        :connection_recycle_time => '30',
-      )}
+      it { is_expected.to_not contain_service('nova-api') }
     end
 
     context 'with custom instance_name_template' do
@@ -319,7 +264,7 @@ describe 'nova::api' do
 
   shared_examples 'nova-api on Debian' do
     context 'with default parameters' do
-      it { is_expected.to contain_service('nova-api- metadata').with(
+      it { is_expected.to contain_service('nova-api-metadata').with(
         :name      => 'nova-api-metadata',
         :ensure    => 'running',
         :hasstatus => true,
@@ -348,7 +293,7 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
-      if facts[:os_package_type] == 'debian'
+      if facts[:operatingsystem] == 'Debian'
         it_behaves_like 'nova-api on Debian'
       end
     end
