@@ -55,7 +55,10 @@ describe 'nova::db::postgresql' do
         }))
       end
 
-      it_configures 'nova::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_configures 'nova::db::postgresql'
+      end
     end
   end
 
