@@ -35,26 +35,60 @@ describe 'nova' do
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__default('nova_config').with(
+          :transport_url        => '<SERVICE DEFAULT>',
+          :rpc_response_timeout => '<SERVICE DEFAULT>',
+          :control_exchange     => '<SERVICE DEFAULT>',
+        )
+        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
+          :rabbit_use_ssl              => '<SERVICE DEFAULT>',
+          :heartbeat_timeout_threshold => '<SERVICE DEFAULT>',
+          :heartbeat_rate              => '<SERVICE DEFAULT>',
+          :heartbeat_in_pthread        => '<SERVICE DEFAULT>',
+          :kombu_reconnect_delay       => '<SERVICE DEFAULT>',
+          :kombu_failover_strategy     => '<SERVICE DEFAULT>',
+          :amqp_durable_queues         => '<SERVICE DEFAULT>',
+          :kombu_compression           => '<SERVICE DEFAULT>',
+          :kombu_ssl_ca_certs          => '<SERVICE DEFAULT>',
+          :kombu_ssl_certfile          => '<SERVICE DEFAULT>',
+          :kombu_ssl_keyfile           => '<SERVICE DEFAULT>',
+          :kombu_ssl_version           => '<SERVICE DEFAULT>',
+          :rabbit_ha_queues            => '<SERVICE DEFAULT>',
+          :rabbit_retry_interval       => '<SERVICE DEFAULT>',
+        )
+        is_expected.to contain_oslo__messaging__amqp('nova_config').with(
+          :server_request_prefix => '<SERVICE DEFAULT>',
+          :broadcast_prefix      => '<SERVICE DEFAULT>',
+          :group_request_prefix  => '<SERVICE DEFAULT>',
+          :container_name        => '<SERVICE DEFAULT>',
+          :idle_timeout          => '<SERVICE DEFAULT>',
+          :trace                 => '<SERVICE DEFAULT>',
+          :ssl_ca_file           => '<SERVICE DEFAULT>',
+          :ssl_cert_file         => '<SERVICE DEFAULT>',
+          :ssl_key_file          => '<SERVICE DEFAULT>',
+          :sasl_mechanisms       => '<SERVICE DEFAULT>',
+          :sasl_config_dir       => '<SERVICE DEFAULT>',
+          :sasl_config_name      => '<SERVICE DEFAULT>',
+          :username              => '<SERVICE DEFAULT>',
+          :password              => '<SERVICE DEFAULT>',
+        )
+        is_expected.to contain_oslo__messaging__notifications('nova_config').with(
+          :transport_url => '<SERVICE DEFAULT>',
+          :driver        => '<SERVICE DEFAULT>',
+          :topics        => '<SERVICE DEFAULT>',
+        )
       end
 
       it 'configures various things' do
-        is_expected.to contain_nova_config('glance/endpoint_override').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova')
-        is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value(platform_params[:lock_path])
+        is_expected.to contain_oslo__concurrency('nova_config').with(
+          :lock_path => platform_params[:lock_path]
+        )
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
@@ -75,15 +109,30 @@ describe 'nova' do
 
       let :params do
         {
-          :glance_endpoint_override                => 'http://localhost:9292',
-          :glance_num_retries                      => 3,
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :long_rpc_timeout                        => '1800',
           :control_exchange                        => 'nova',
+          :rabbit_use_ssl                          => true,
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
           :rabbit_heartbeat_in_pthread             => true,
+          :kombu_reconnect_delay                   => '5.0',
+          :amqp_durable_queues                     => true,
+          :kombu_compression                       => 'gzip',
+          :kombu_ssl_ca_certs                      => '/etc/ca.cert',
+          :kombu_ssl_certfile                      => '/etc/certfile',
+          :kombu_ssl_keyfile                       => '/etc/key',
+          :kombu_ssl_version                       => 'TLSv1',
+          :rabbit_ha_queues                        => true,
+          :rabbit_retry_interval                   => '1',
+          :amqp_idle_timeout                       => '60',
+          :amqp_trace                              => true,
+          :amqp_ssl_ca_file                        => '/etc/ca.cert',
+          :amqp_ssl_cert_file                      => '/etc/certfile',
+          :amqp_ssl_key_file                       => '/etc/key',
+          :amqp_username                           => 'amqp_user',
+          :amqp_password                           => 'password',
           :lock_path                               => '/var/locky/path',
           :state_path                              => '/var/lib/nova2',
           :service_down_time                       => '120',
@@ -95,7 +144,6 @@ describe 'nova' do
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
           :report_interval                         => '60',
-          :cross_az_attach                         => true,
           :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
           :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
@@ -130,24 +178,45 @@ describe 'nova' do
         })
       end
 
-      it 'configures glance parameters' do
-        is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
-        is_expected.to contain_nova_config('glance/num_retries').with_value(3)
-      end
-
       it 'configures auth_strategy' do
         is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
-        is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
-        is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
-        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
+        is_expected.to contain_oslo__messaging__default('nova_config').with(
+          :transport_url        => 'rabbit://rabbit_user:password@localhost:5673',
+          :rpc_response_timeout => '30',
+          :control_exchange     => 'nova',
+        )
+        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
+          :rabbit_use_ssl              => true,
+          :heartbeat_timeout_threshold => '60',
+          :heartbeat_rate              => '10',
+          :heartbeat_in_pthread        => true,
+          :kombu_reconnect_delay       => '5.0',
+          :amqp_durable_queues         => true,
+          :kombu_compression           => 'gzip',
+          :kombu_ssl_ca_certs          => '/etc/ca.cert',
+          :kombu_ssl_certfile          => '/etc/certfile',
+          :kombu_ssl_keyfile           => '/etc/key',
+          :kombu_ssl_version           => 'TLSv1',
+          :rabbit_ha_queues            => true,
+          :rabbit_retry_interval       => '1',
+        )
+        is_expected.to contain_oslo__messaging__amqp('nova_config').with(
+          :idle_timeout  => '60',
+          :trace         => true,
+          :ssl_ca_file   => '/etc/ca.cert',
+          :ssl_cert_file => '/etc/certfile',
+          :ssl_key_file  => '/etc/key',
+          :username      => 'amqp_user',
+          :password      => 'password',
+        )
+        is_expected.to contain_oslo__messaging__notifications('nova_config').with(
+          :transport_url => 'rabbit://rabbit_user:password@localhost:5673',
+          :driver        => 'ceilometer.compute.nova_notifier',
+          :topics        => 'openstack',
+        )
       end
 
       it 'configures host' do
@@ -170,15 +239,14 @@ describe 'nova' do
 
       it 'configures various things' do
         is_expected.to contain_nova_config('DEFAULT/state_path').with_value('/var/lib/nova2')
-        is_expected.to contain_nova_config('oslo_concurrency/lock_path').with_value('/var/locky/path')
+        is_expected.to contain_oslo__concurrency('nova_config').with(
+          :lock_path => '/var/locky/path'
+        )
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('120')
-        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
-        is_expected.to contain_nova_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
-        is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
         is_expected.to contain_nova_config('vif_plug_ovs/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
+        is_expected.to contain_nova_config('DEFAULT/long_rpc_timeout').with_value('1800')
         is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
         is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
@@ -190,8 +258,8 @@ describe 'nova' do
       context 'with multiple notification_driver' do
         before { params.merge!( :notification_driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']) }
 
-        it { is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value(
-          ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']
+        it { is_expected.to contain_oslo__messaging__notifications('nova_config').with(
+          :driver => ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier'],
         ) }
       end
     end
@@ -216,121 +284,6 @@ describe 'nova' do
       end
     end
 
-    context 'with kombu_reconnect_delay set to 5.0' do
-      let :params do
-        { :kombu_reconnect_delay => '5.0' }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('5.0')
-      end
-    end
-
-    context 'with rabbit_ha_queues set to true' do
-      let :params do
-        { :rabbit_ha_queues => true }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-      end
-    end
-
-    context 'with rabbit_ha_queues set to false' do
-      let :params do
-        { :rabbit_ha_queues => false }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(false)
-      end
-    end
-
-    context 'with amqp_durable_queues parameter' do
-      let :params do
-        { :amqp_durable_queues => true }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
-        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-          :rabbit_use_ssl => '<SERVICE DEFAULT>',
-        )
-      end
-    end
-
-    context 'with rabbit ssl enabled with kombu' do
-      let :params do
-        { :rabbit_use_ssl     => true,
-          :kombu_ssl_ca_certs => '/etc/ca.cert',
-          :kombu_ssl_certfile => '/etc/certfile',
-          :kombu_ssl_keyfile  => '/etc/key',
-          :kombu_ssl_version  => 'TLSv1', }
-      end
-
-      it { is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-        :rabbit_use_ssl     => true,
-        :kombu_ssl_ca_certs => '/etc/ca.cert',
-        :kombu_ssl_certfile => '/etc/certfile',
-        :kombu_ssl_keyfile  => '/etc/key',
-        :kombu_ssl_version  => 'TLSv1'
-      )}
-    end
-
-    context 'with rabbit ssl enabled without kombu' do
-      let :params do
-        { :rabbit_use_ssl => true, }
-      end
-
-      it { is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
-        :rabbit_use_ssl => true,
-      )}
-    end
-
-    context 'with amqp default parameters' do
-      it 'configures amqp' do
-        is_expected.to contain_nova_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with amqp overridden parameters' do
-      let :params do
-        { :amqp_idle_timeout  => '60',
-          :amqp_trace         => true,
-          :amqp_ssl_ca_file   => '/etc/ca.cert',
-          :amqp_ssl_cert_file => '/etc/certfile',
-          :amqp_ssl_key_file  => '/etc/key',
-          :amqp_username      => 'amqp_user',
-          :amqp_password      => 'password',
-        }
-      end
-
-      it 'configures amqp overide' do
-        is_expected.to contain_nova_config('oslo_messaging_amqp/idle_timeout').with_value('60')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/trace').with_value('true')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_ca_file').with_value('/etc/ca.cert')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_cert_file').with_value('/etc/certfile')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_key_file').with_value('/etc/key')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/username').with_value('amqp_user')
-        is_expected.to contain_nova_config('oslo_messaging_amqp/password').with_value('password')
-      end
-    end
-
     context 'with ssh public key' do
       let :params do
         {
