@@ -23,6 +23,9 @@ describe 'nova::metadata::novajoin::auth' do
         :password            => 'novajoin_password',
         :email               => 'novajoin@localhost',
         :tenant              => 'services',
+        :roles               => ['admin'],
+        :system_scope        => 'all',
+        :system_roles        => [],
         :public_url          => 'http://127.0.0.1:9090',
         :internal_url        => 'http://127.0.0.1:9090',
         :admin_url           => 'http://127.0.0.1:9090',
@@ -42,6 +45,9 @@ describe 'nova::metadata::novajoin::auth' do
           :service_name        => 'alt_service',
           :service_type        => 'alt_compute-vendordata-plugin',
           :region              => 'RegionTwo',
+          :roles               => ['admin', 'service'],
+          :system_scope        => 'alt_all',
+          :system_roles        => ['admin', 'member', 'reader'],
           :public_url          => 'https://10.10.10.10:80',
           :internal_url        => 'http://10.10.10.11:81',
           :admin_url           => 'http://10.10.10.12:81' }
@@ -59,6 +65,9 @@ describe 'nova::metadata::novajoin::auth' do
         :password            => 'novajoin_password',
         :email               => 'alt_novajoin@alt_localhost',
         :tenant              => 'alt_service',
+        :roles               => ['admin', 'service'],
+        :system_scope        => 'alt_all',
+        :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
         :internal_url        => 'http://10.10.10.11:81',
         :admin_url           => 'http://10.10.10.12:81',
