@@ -25,6 +25,7 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/auth_type').with_value(default_params[:auth_type])
         is_expected.to contain_nova_config('placement/project_name').with_value(default_params[:project_name])
         is_expected.to contain_nova_config('placement/project_domain_name').with_value(default_params[:project_domain_name])
+        is_expected.to contain_nova_config('placement/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('placement/region_name').with_value(default_params[:region_name])
         is_expected.to contain_nova_config('placement/valid_interfaces').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('placement/username').with_value(default_params[:username])
@@ -40,7 +41,7 @@ describe 'nova::placement' do
           :project_name        => 'service',
           :project_domain_name => 'default',
           :region_name         => 'RegionTwo',
-          :valid_interfaces    => 'internal',
+          :valid_interfaces    => 'internal,public',
           :username            => 'placement2',
           :user_domain_name    => 'default',
           :auth_url            => 'https://127.0.0.1:5000/v3',
@@ -52,6 +53,7 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/auth_type').with_value(params[:auth_type])
         is_expected.to contain_nova_config('placement/project_name').with_value(params[:project_name])
         is_expected.to contain_nova_config('placement/project_domain_name').with_value(params[:project_domain_name])
+        is_expected.to contain_nova_config('placement/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('placement/region_name').with_value(params[:region_name])
         is_expected.to contain_nova_config('placement/valid_interfaces').with_value(params[:valid_interfaces])
         is_expected.to contain_nova_config('placement/username').with_value(params[:username])
@@ -59,6 +61,32 @@ describe 'nova::placement' do
         is_expected.to contain_nova_config('placement/auth_url').with_value(params[:auth_url])
       end
     end
+
+    context 'when valid_interfaces is an array' do
+      before do
+        params.merge!(
+          :valid_interfaces => ['internal', 'public']
+        )
+      end
+
+      it 'configures the valid_interfaces parameter with a commma-separated string' do
+        is_expected.to contain_nova_config('placement/valid_interfaces').with_value('internal,public')
+      end
+    end
+
+    context 'when system_scope is set' do
+      before do
+        params.merge!(
+          :system_scope => 'all'
+        )
+      end
+
+      it 'configures system-scoped credential' do
+        is_expected.to contain_nova_config('placement/project_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('placement/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('placement/system_scope').with_value(params[:system_scope])
+      end
+    end
   end
 
   on_supported_os({
